@@ -52,8 +52,8 @@ static inline _Complex double * _pCd(doublecomplex *z) {return (_Complex double*
 #endif
 #define pCf(z) (*_pCf(z))
 #define pCd(z) (*_pCd(z))
-typedef int logical;
-typedef short int shortlogical;
+typedef blasint logical;
+
 typedef char logical1;
 typedef char integer1;
 
@@ -260,7 +260,7 @@ static char junk[] = "\n@(#)LIBF77 VERSION 19990503\n";
 
 /* procedure parameter types for -A and -C++ */
 
-#define F2C_proc_par_types 1
+
 #ifdef __cplusplus
 typedef logical (*L_fp)(...);
 #else
@@ -654,7 +654,7 @@ static inline void zdotu_(doublecomplex *z, integer *n_, doublecomplex *x, integ
 /* > \ingroup realGEcomputational */
 
 /*  ===================================================================== */
-/* Subroutine */ int sgeequb_(integer *m, integer *n, real *a, integer *lda, 
+/* Subroutine */ void sgeequb_(integer *m, integer *n, real *a, integer *lda, 
 	real *r__, real *c__, real *rowcnd, real *colcnd, real *amax, integer 
 	*info)
 {
@@ -700,7 +700,7 @@ static inline void zdotu_(doublecomplex *z, integer *n_, doublecomplex *x, integ
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("SGEEQUB", &i__1, (ftnlen)7);
-	return 0;
+	return;
     }
 
 /*     Quick return if possible. */
@@ -709,7 +709,7 @@ static inline void zdotu_(doublecomplex *z, integer *n_, doublecomplex *x, integ
 	*rowcnd = 1.f;
 	*colcnd = 1.f;
 	*amax = 0.f;
-	return 0;
+	return;
     }
 
 /*     Get machine constants.  Assume SMLNUM is a power of the radix. */
@@ -772,7 +772,7 @@ static inline void zdotu_(doublecomplex *z, integer *n_, doublecomplex *x, integ
 	for (i__ = 1; i__ <= i__1; ++i__) {
 	    if (r__[i__] == 0.f) {
 		*info = i__;
-		return 0;
+		return;
 	    }
 /* L50: */
 	}
@@ -846,7 +846,7 @@ static inline void zdotu_(doublecomplex *z, integer *n_, doublecomplex *x, integ
 	for (j = 1; j <= i__1; ++j) {
 	    if (c__[j] == 0.f) {
 		*info = *m + j;
-		return 0;
+		return;
 	    }
 /* L110: */
 	}
@@ -869,7 +869,7 @@ static inline void zdotu_(doublecomplex *z, integer *n_, doublecomplex *x, integ
 	*colcnd = f2cmax(rcmin,smlnum) / f2cmin(rcmax,bignum);
     }
 
-    return 0;
+    return;
 
 /*     End of SGEEQUB */
 
