@@ -52,8 +52,8 @@ static inline _Complex double * _pCd(doublecomplex *z) {return (_Complex double*
 #endif
 #define pCf(z) (*_pCf(z))
 #define pCd(z) (*_pCd(z))
-typedef int logical;
-typedef short int shortlogical;
+typedef blasint logical;
+
 typedef char logical1;
 typedef char integer1;
 
@@ -260,7 +260,7 @@ static char junk[] = "\n@(#)LIBF77 VERSION 19990503\n";
 
 /* procedure parameter types for -A and -C++ */
 
-#define F2C_proc_par_types 1
+
 #ifdef __cplusplus
 typedef logical (*L_fp)(...);
 #else
@@ -667,7 +667,7 @@ f"> */
 /* > \endverbatim */
 /* > */
 /*  ===================================================================== */
-/* Subroutine */ int zpbstf_(char *uplo, integer *n, integer *kd, 
+/* Subroutine */ void zpbstf_(char *uplo, integer *n, integer *kd, 
 	doublecomplex *ab, integer *ldab, integer *info)
 {
     /* System generated locals */
@@ -675,13 +675,14 @@ f"> */
     doublereal d__1;
 
     /* Local variables */
-    extern /* Subroutine */ int zher_(char *, integer *, doublereal *, 
+    extern /* Subroutine */ void zher_(char *, integer *, doublereal *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *);
     integer j, m;
     extern logical lsame_(char *, char *);
     logical upper;
     integer km;
-    extern /* Subroutine */ int xerbla_(char *, integer *, ftnlen), zdscal_(
+    extern /* Subroutine */ int xerbla_(char *, integer *, ftnlen);
+    extern void zdscal_(
 	    integer *, doublereal *, doublecomplex *, integer *), zlacgv_(
 	    integer *, doublecomplex *, integer *);
     doublereal ajj;
@@ -719,13 +720,13 @@ f"> */
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("ZPBSTF", &i__1, (ftnlen)6);
-	return 0;
+	return;
     }
 
 /*     Quick return if possible */
 
     if (*n == 0) {
-	return 0;
+	return;
     }
 
 /* Computing MAX */
@@ -871,11 +872,11 @@ f"> */
 /* L40: */
 	}
     }
-    return 0;
+    return;
 
 L50:
     *info = j;
-    return 0;
+    return;
 
 /*     End of ZPBSTF */
 
